@@ -3,6 +3,7 @@ import os
 
 LEVEL = os.environ.get("DOTFILES_LOGGING_LEVEL", "INFO")
 FORMAT = os.environ.get("DOTFILES_LOGGING_FORMAT", "%(message)s")
+SHOW_PATH = 'SHOW_PATH' in os.environ
 SIMPLE_LOGGING = 'DOTFILES_SIMPLE_LOGGING' in os.environ
 
 if SIMPLE_LOGGING:
@@ -10,7 +11,7 @@ if SIMPLE_LOGGING:
     handler = StreamHandler()
 else:
     from rich.logging import RichHandler
-    handler = RichHandler()
+    handler = RichHandler(show_path=SHOW_PATH)
 
 logging.basicConfig(
     level=LEVEL, format=FORMAT, datefmt="[%X]", handlers=[handler]
